% 
% Generate Figure 5
%
% by Stephane Lhuissier

clear all; clc;
%
addpath '../library'
%
load load_draws_msVAR.mat

ndraws = 1000; % # draws
%
bupp    = 84; % upper error band (percentile)
blow    = 16; % lower error band (percentile)
bmed    = 50; % impulse response percentile
nRow    = 3;  % number of row in Figure
nCol    = 3;  % number of column in Figure
%
nstates = 2;  % # regimes governing equation coefficients
nvar    = 4;  % # variables
nexo    = 1;  % # constant
nlags   = 4;  % # lags
imstp   = 37; % horizon
M       = 4;  % position of the structural shock  
%
list_bvar_name={'Industrial production (%)','Prices (%)','EONIA (p.p)','EBP (p.p)'};
%
irf = zeros(imstp,nvar,nstates,ndraws);
%
rootsinv_store = zeros(size(Fgibbs(:,:,:,1),1)-1,2);
%
cc = [];

for idx_draws=1:ndraws
    %
    imf3gibbs=zeros(imstp,nvar,nvar,nstates);
    %
    fprintf(1,'\nSimulation step %2.0f of %2.0f',[idx_draws,ndraws])
    for idx_ns=1:nstates
        %
        Bgibbs=Fgibbs(:,:,idx_ns,idx_draws)/Agibbs(:,:,idx_ns,idx_draws);
        %
        swish=inv(Agibbs(:,:,idx_ns,idx_draws));
        %
        imfgibbs = fn_impulse(Bgibbs,swish,[nvar nlags imstp]);
        % imf3: row--steps, column--nvar responses, 3rd dimension--nvar shocks		
        imf3gibbs(:,:,:,idx_ns) = reshape(imfgibbs,size(imfgibbs,1),nvar,nvar);
        % normalize VIX shock at a 100 basis point VIX increase
        Mult = 0.25/swish(M,M);
        ii = 1;
        for ii=1:nvar
            irf(:,ii,idx_ns,idx_draws) = Mult*imf3gibbs(:,ii,M,idx_ns);
            ii = ii+1;
        end;
        %
        rootsinv = sort(abs(fn_varoots(Bgibbs,nvar,nlags)));
        %
        rootsinv_store(:,idx_ns) = rootsinv;
        %
        clear swish Bgibbs imfgibbs Mult
    end
    if rootsinv_store(end,1) <=1.01 && rootsinv_store(end,2) <=1.01 % avoid explosive paths
        cc = [cc idx_draws];
    end
end

irf1    = irf(:,:,:,cc');
ndraws1 = size(cc,2);

% Difference in IRFs between regime 1 and regime 2
irf_diff = squeeze(irf1(:,:,1,:)-irf1(:,:,2,:));

% memory allocation
irf_quan      = zeros(imstp,nvar,3,nstates);
irf_diff_quan = zeros(imstp,nvar,3);

for idx_ns=1:nstates
    irf_to_shock=squeeze(irf1(:,:,idx_ns,:));
    
    % sort the IRFs
    sort_irf = sort(irf_to_shock,3);
    
    % computing mean, upper and lower bands for IRFs 
    irf_quan(:,:,1,idx_ns) = sort_irf(:,:,round(ndraws1*blow/100));
    irf_quan(:,:,2,idx_ns) = sort_irf(:,:,round(ndraws1*bmed/100));
    irf_quan(:,:,3,idx_ns) = sort_irf(:,:,round(ndraws1*bupp/100));
    %
    clear irf_to_shock sort_irf
end

% sort the IRFs diff
sort_irf_diff = sort(irf_diff,3);

% computing mean, upper and lower bands for IRFs 
irf_diff_quan(:,:,1) = sort_irf_diff(:,:,round(ndraws1*blow/100));
irf_diff_quan(:,:,2) = sort_irf_diff(:,:,round(ndraws1*bmed/100));
irf_diff_quan(:,:,3) = sort_irf_diff(:,:,round(ndraws1*bupp/100));
    
% Figure
t = 1:imstp;

idx_label1=1:3:nvar*3;
idx_label2=2:3:nvar*3;
idx_label3=3:3:nvar*3;

make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.01 0.03], [0.06 0.04], [0.08 0.006]);
if ~make_it_tight,  clear subplot;  end

figure
for ii=1:nvar
    subplot(4,3,idx_label1(ii)); 
        plot(t,zeros(imstp,1),'color','k','LineStyle',':','LineWidth',2.5)
        hold on
        a=plot(irf_quan(:,ii,3,1),'LineStyle','-','color',[0 0.4470 0.7410],'LineWidth',1.0);
        hold on
        plot(irf_quan(:,ii,1,1),'LineStyle','-','color',[0 0.4470 0.7410],'LineWidth',1.0)
        hold on
        b=plot(irf_quan(:,ii,2,1),'LineStyle','-.','color',[0 0.4470 0.7410],'LineWidth',1.0);
        xlim([1 37])
        ylabel(list_bvar_name{ii})
        ylim([ min([irf_quan(:,ii,3,1);irf_quan(:,ii,1,1);irf_quan(:,ii,3,2);irf_quan(:,ii,1,2); irf_diff_quan(:,ii,3); irf_diff_quan(:,ii,1)]) ...
               max([irf_quan(:,ii,3,1);irf_quan(:,ii,1,1);irf_quan(:,ii,3,2);irf_quan(:,ii,1,2); irf_diff_quan(:,ii,3); irf_diff_quan(:,ii,1)]) ])
        if ii==1
            title('Tranquil Regime [1]')
        end
        if ii==nvar
            xlabel('months after shock')
        end
        
        if ii<=3
            set(gca,'Xticklabel','')
        end
        
        if ii==1
           legend([b,a],'Median','68% error bands','Location','SouthEast')
           set(gca,'ytick',[-4 -2 0 2 4])
        end
        
        set(gca,'xtick',[6 12 24 36])
        set(gca,'xgrid','on') 
        set(gca,'ygrid','on')
        
    subplot(4,3,idx_label2(ii));
        plot(t,zeros(imstp,1),'color','k','LineStyle',':','LineWidth',2.5)
        hold on
        plot(irf_quan(:,ii,3,2),'LineStyle','-','color',[0 0.4470 0.7410],'LineWidth',1.0)
        hold on
        plot(irf_quan(:,ii,1,2),'LineStyle','-','color',[0 0.4470 0.7410],'LineWidth',1.0)
        hold on
        plot(irf_quan(:,ii,2,2),'LineStyle','-.','color',[0 0.4470 0.7410],'LineWidth',1.0)
        xlim([1 37])
        ylim([ min([irf_quan(:,ii,3,1);irf_quan(:,ii,1,1);irf_quan(:,ii,3,2);irf_quan(:,ii,1,2); irf_diff_quan(:,ii,3); irf_diff_quan(:,ii,1)]) ...
               max([irf_quan(:,ii,3,1);irf_quan(:,ii,1,1);irf_quan(:,ii,3,2);irf_quan(:,ii,1,2); irf_diff_quan(:,ii,3); irf_diff_quan(:,ii,1)]) ])
        if ii==1
            title('Distress Regime [2]')
            set(gca,'ytick',[-4 -2 0 2 4])
        end
        if ii==nvar
            xlabel('months after shock')
        end
        if ii<=3
            set(gca,'Xticklabel','')
        end
        set(gca,'Yticklabel','')
        set(gca,'xtick',[6 12 24 36])
        set(gca,'xgrid','on')
        set(gca,'ygrid','on')
        
    subplot(4,3,idx_label3(ii));
        plot(t,zeros(imstp,1),'color','k','LineStyle',':','LineWidth',2.5)
        hold on
        plot(irf_diff_quan(:,ii,3),'LineStyle','-','color',[0 0.4470 0.7410],'LineWidth',1.0)
        hold on
        plot(irf_diff_quan(:,ii,1),'LineStyle','-','color',[0 0.4470 0.7410],'LineWidth',1.0)
        hold on
        plot(irf_diff_quan(:,ii,2),'LineStyle','-.','color',[0 0.4470 0.7410],'LineWidth',1.0)
        xlim([1 37])
        ylim([ min([irf_quan(:,ii,3,1);irf_quan(:,ii,1,1);irf_quan(:,ii,3,2);irf_quan(:,ii,1,2);irf_diff_quan(:,ii,3); irf_diff_quan(:,ii,1)]) ...
               max([irf_quan(:,ii,3,1);irf_quan(:,ii,1,1);irf_quan(:,ii,3,2);irf_quan(:,ii,1,2);irf_diff_quan(:,ii,3); irf_diff_quan(:,ii,1)]) ])
        if ii==1
            title('[1]-[2]')
            set(gca,'ytick',[-4 -2 0 2 4])
        end
        if ii==nvar
            xlabel('months after shock')
        end
        if ii<=3
            set(gca,'Xticklabel','')
        end
        set(gca,'Yticklabel','')
        set(gca,'xtick',[6 12 24 36])
        set(gca,'xgrid','on')
        set(gca,'ygrid','on')
end
% 
set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[7 8]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 7 8]);

set(gcf,'renderer','painters');
%eval(['print -dpdf Fig5']);
