%
% Generate Figure 2
%
% by Stephane Lhuissier

clear all; clc;

addpath '../library'
addpath '../MS-SBVARs/benchmark'

load ../data/EAdata_1999M10_2016M6.mat

% first year to use in estimation
yrStart = 2000;
% first quarter or month to use in estimation
qmStart = 2;
% last year to use in estimation
yrEnd = 2016;
% last quarter or month to use in estimation
qmEnd = 6;
% create date 
[date, n] = fn_calyrqm(12, [yrStart qmStart], [yrEnd qmEnd]);
qdates=zeros(n,1);
for ki=1:n
   qdates(ki) = date(1,1) + (date(1,2)+ki-2)/12;
end

[Qhat, Ahat, Fhat, Zhat] = load_flat_file('Run_msVAR');

nstates = 4;
nvar    = size(Ahat,1);
nexo    = 1;
lags    = (size(Fhat,1)-nexo)/nvar;
%
xdd = [IP P RE EBP];

%
Ehat      = zeros(nvar,nstates);
for h_idx=1:nstates
    Ehat(:,h_idx) = sqrt(diag(Zhat(:,:,h_idx)));
    Ehat(:,h_idx) = sqrt(diag(Zhat(:,:,h_idx)));
    Ehat(:,h_idx) = sqrt(diag(Zhat(:,:,h_idx)));
    Ehat(:,h_idx) = sqrt(diag(Zhat(:,:,h_idx)));
end
%
Qstar = kron(Qhat(:,:,1),Qhat(:,:,2));

% Evaluate the likelihood
[logLik, lik_mat, pr_st0, pr_stl0] = lik_ms_sbvar(xdd, Ahat, Fhat, Ehat, Qstar, nstates, lags);

% Kim (1994) filter 
[pr_sT, pr_joint_sT] = SmoothedProbabilities(pr_st0, pr_stl0, Qstar);

%
make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.11 0.01], [0.115 0.06], [0.05 0.01]);
if ~make_it_tight,  clear subplot;  end
%

figure
subplot(1,2,1)
a=area([2008.00 2009.25], [130 130],-10);
hold on
b=area([2011.50 2012.75], [130 130],-10);
hold on
plot(qdates,pr_sT(:,1)+pr_sT(:,2),'Linewidth',1.5)
ylabel('prob.')
xlabel('years')
xlim([1998 2018])
ylim([-0.05 1.05])
grid on
title('"High-volatility" Regime')
set(a,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(b,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(gca,'layer','top')

subplot(1,2,2)
a=area([2008.00 2009.25], [130 130],-10);
hold on
b=area([2011.50 2012.75], [130 130],-10);
hold on
plot(qdates,pr_sT(:,2)+pr_sT(:,4),'Linewidth',1.5)
xlabel('years')
xlim([1998 2018])
ylim([-0.05 1.05])
set(gca,'Yticklabel','')
grid on
title('"High-stress-coefficients" Regime')
set(a,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(b,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(gca,'layer','top')

set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[10 4]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 10 4]);

set(gcf,'renderer','painters');
%eval(['print -dpdf Fig3']);



