% 
% Generate Table 7
%
% by Stephane Lhuissier

clear all; clc;
%
addpath '../library'
%
load load_draws_msVAR.mat
%
ndraws   = 1000; % # draws
%
bupp     = 84;   % upper error band (percentile)
blow     = 16;   % lower error band (percentile)
bmed     = 50;   % impulse response percentile
nRow     = 3;    % number of row in Figure
nCol     = 3;    % number of column in Figure
%
nstates = 4;                          % # total regimes
nvar    = size(Agibbs,1);             % # variables
nexo    = 1;                          % # constant
nlags   = (size(Fgibbs,1)-nexo)/nvar; % # lags
imstp   = 37;                         % horizon
M       = 4;                          % position of the structural shock
%
vds = zeros(imstp,nvar,nstates,ndraws);
%
rootsinv_store = zeros(size(Fgibbs,1)-nexo,2);
%
cc = [];

for idx_draws=1:ndraws
    %
    imf3gibbs=zeros(imstp,nvar,nvar,nstates);
    vdsgibbs=zeros(imstp,nvar,nvar,nstates);
    %
    fprintf(1,'\nSimulation step %2.0f of %2.0f',[idx_draws,ndraws])
    for idx_ns=1:nstates
        %
        Bgibbs=Fgibbs(:,:,idx_ns,idx_draws)/Agibbs(:,:,idx_ns,idx_draws);
        %
        swish=inv(Agibbs(:,:,idx_ns,idx_draws)*sqrt(Zgibbs(:,:,idx_ns,idx_draws)));
        %
        imfgibbs = fn_impulse(Bgibbs,swish,[nvar nlags imstp]);
        % imf3: row--steps, column--nvar responses, 3rd dimension--nvar shocks		
        imf3gibbs(:,:,:,idx_ns) = reshape(imfgibbs,size(imfgibbs,1),nvar,nvar);
        % vds
        vdsgibbs(:,:,:,idx_ns)=fn_vds(imf3gibbs(:,:,:,idx_ns));
        %
        vds(:,:,idx_ns,idx_draws)=squeeze(vdsgibbs(:,:,M,idx_ns));
        %
        rootsinv = sort(abs(fn_varoots(Bgibbs,nvar,nlags)));
        %
        rootsinv_store(:,idx_ns) = rootsinv;
        %
        clear swish Bgibbs imfgibbs Mult
    end
    if rootsinv_store(end,1) <=1.01 && rootsinv_store(end,2) <=1.01
        cc = [cc idx_draws];
    end
end

ndraws1 = size(cc,2);
vds1    = vds(:,:,:,cc');

% memory allocation
vds_quan = zeros(imstp,nvar,3,nstates);

for idx_ns=1:nstates
    vds_to_shock=squeeze(vds1(:,:,idx_ns,:));
    
    % sort the IRFs
    sort_vds = sort(vds_to_shock,3);
    
    % computing mean, upper and lower bands for IRFs 
    vds_quan(:,:,1,idx_ns) = sort_vds(:,:,round(ndraws1*blow/100));
    vds_quan(:,:,2,idx_ns) = sort_vds(:,:,round(ndraws1*bmed/100));
    vds_quan(:,:,3,idx_ns) = sort_vds(:,:,round(ndraws1*bupp/100));
    %
    clear vds_to_shock sort_vds
end

fprintf('\n')
fprintf('\\begin{table}\n')
fprintf('\\center\n')
fprintf('\\label{vds_2c2v}\n')
fprintf('\\begin{tabular}{ccccc}\n')
fprintf(' \\hline\n ')
fprintf(' \\hline\n')
fprintf(' Horizon & IP & Prices & EONIA & EBP \\\\\n')
fprintf(' \\hline\n')
fprintf(' \\multicolumn{5}{c}{$s_t^{\\text{c}}=1$, $s_t^{\\text{v}}=1$} \\\\\n')
fprintf(' \\multicolumn{5}{c}{(Tranquil regime, Low-volatility regime)} \\\\\n')
fprintf(' \\hline\n')
fprintf(' 6M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(7,1,1,1), vds_quan(7,1,3,1), vds_quan(7,1,2,1),  ...
          vds_quan(7,2,1,1), vds_quan(7,2,3,1), vds_quan(7,2,2,1),  ...
          vds_quan(7,3,1,1), vds_quan(7,3,3,1), vds_quan(7,3,2,1),  ...
          vds_quan(7,4,1,1), vds_quan(7,4,3,1), vds_quan(7,4,2,1))
fprintf(' 12M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(13,1,1,1), vds_quan(13,1,3,1), vds_quan(13,1,2,1),  ...
          vds_quan(13,2,1,1), vds_quan(13,2,3,1), vds_quan(13,2,2,1),  ...
          vds_quan(13,3,1,1), vds_quan(13,3,3,1), vds_quan(13,3,2,1),  ...
          vds_quan(13,4,1,1), vds_quan(13,4,3,1), vds_quan(13,4,2,1))
fprintf(' 24M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(25,1,1,1), vds_quan(25,1,3,1), vds_quan(25,1,2,1),  ...
          vds_quan(25,2,1,1), vds_quan(25,2,3,1), vds_quan(25,2,2,1),  ...
          vds_quan(25,3,1,1), vds_quan(25,3,3,1), vds_quan(25,3,2,1),  ...
          vds_quan(25,4,1,1), vds_quan(25,4,3,1), vds_quan(25,4,2,1))
fprintf(' 36M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(37,1,1,1), vds_quan(37,1,3,1), vds_quan(37,1,2,1),  ...
          vds_quan(37,2,1,1), vds_quan(37,2,3,1), vds_quan(37,2,2,1),  ...
          vds_quan(37,3,1,1), vds_quan(37,3,3,1), vds_quan(37,3,2,1),  ...
          vds_quan(37,4,1,1), vds_quan(37,4,3,1), vds_quan(37,4,2,1))
fprintf(' \\hline\n')
fprintf(' \\multicolumn{5}{c}{$s_t^{\\text{c}}=2$, $s_t^{\\text{v}}=1$} \\\\\n')
fprintf(' \\multicolumn{5}{c}{(Distress regime, Low-volatility regime)} \\\\\n')
fprintf(' \\hline\n')
fprintf(' 6M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(7,1,1,2), vds_quan(7,1,3,2), vds_quan(7,1,2,2),  ...
          vds_quan(7,2,1,2), vds_quan(7,2,3,2), vds_quan(7,2,2,2),  ...
          vds_quan(7,3,1,2), vds_quan(7,3,3,2), vds_quan(7,3,2,2),  ...
          vds_quan(7,4,1,2), vds_quan(7,4,3,2), vds_quan(7,4,2,2))
fprintf(' 12M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(13,1,1,2), vds_quan(13,1,3,2), vds_quan(13,1,2,2),  ...
          vds_quan(13,2,1,2), vds_quan(13,2,3,2), vds_quan(13,2,2,2),  ...
          vds_quan(13,3,1,2), vds_quan(13,3,3,2), vds_quan(13,3,2,2),  ...
          vds_quan(13,4,1,2), vds_quan(13,4,3,2), vds_quan(13,4,2,2))
fprintf(' 24M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(25,1,1,2), vds_quan(25,1,3,2), vds_quan(25,1,2,2),  ...
          vds_quan(25,2,1,2), vds_quan(25,2,3,2), vds_quan(25,2,2,2),  ...
          vds_quan(25,3,1,2), vds_quan(25,3,3,2), vds_quan(25,3,2,2),  ...
          vds_quan(25,4,1,2), vds_quan(25,4,3,2), vds_quan(25,4,2,2))
fprintf(' 36M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(37,1,1,2), vds_quan(37,1,3,2), vds_quan(37,1,2,2),  ...
          vds_quan(37,2,1,2), vds_quan(37,2,3,2), vds_quan(37,2,2,2),  ...
          vds_quan(37,3,1,2), vds_quan(37,3,3,2), vds_quan(37,3,2,2),  ...
          vds_quan(37,4,1,2), vds_quan(37,4,3,2), vds_quan(37,4,2,2))
fprintf(' \\hline\n')
fprintf(' \\multicolumn{5}{c}{$s_t^{\\text{c}}=1$, $s_t^{\\text{v}}=2$} \\\\\n')
fprintf(' \\multicolumn{5}{c}{(Tranquil regime, High-volatility regime)} \\\\\n')
fprintf(' \\hline\n')
fprintf(' 6M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(7,1,1,3), vds_quan(7,1,3,3), vds_quan(7,1,2,3),  ...
          vds_quan(7,2,1,3), vds_quan(7,2,3,3), vds_quan(7,2,2,3),  ...
          vds_quan(7,3,1,3), vds_quan(7,3,3,3), vds_quan(7,3,2,3),  ...
          vds_quan(7,4,1,3), vds_quan(7,4,3,3), vds_quan(7,4,2,3))
fprintf(' 12M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(13,1,1,3), vds_quan(13,1,3,3), vds_quan(13,1,2,3),  ...
          vds_quan(13,2,1,3), vds_quan(13,2,3,3), vds_quan(13,2,2,3),  ...
          vds_quan(13,3,1,3), vds_quan(13,3,3,3), vds_quan(13,3,2,3),  ...
          vds_quan(13,4,1,3), vds_quan(13,4,3,3), vds_quan(13,4,2,3))
fprintf(' 24M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(25,1,1,3), vds_quan(25,1,3,3), vds_quan(25,1,2,3),  ...
          vds_quan(25,2,1,3), vds_quan(25,2,3,3), vds_quan(25,2,2,3),  ...
          vds_quan(25,3,1,3), vds_quan(25,3,3,3), vds_quan(25,3,2,3),  ...
          vds_quan(25,4,1,3), vds_quan(25,4,3,3), vds_quan(25,4,2,3))
fprintf(' 36M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(37,1,1,3), vds_quan(37,1,3,3), vds_quan(37,1,2,3),  ...
          vds_quan(37,2,1,3), vds_quan(37,2,3,3), vds_quan(37,2,2,3),  ...
          vds_quan(37,3,1,3), vds_quan(37,3,3,3), vds_quan(37,3,2,3),  ...
          vds_quan(37,4,1,3), vds_quan(37,4,3,3), vds_quan(37,4,2,3))
fprintf(' \\hline\n')
fprintf(' \\multicolumn{5}{c}{$s_t^{\\text{c}}=2$, $s_t^{\\text{v}}=2$} \\\\\n')
fprintf(' \\multicolumn{5}{c}{(Distress regime, High-volatility regime)} \\\\\n')
fprintf(' \\hline\n')
fprintf(' 6M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(7,1,1,4), vds_quan(7,1,3,4), vds_quan(7,1,2,4),  ...
          vds_quan(7,2,1,4), vds_quan(7,2,3,4), vds_quan(7,2,2,4),  ...
          vds_quan(7,3,1,4), vds_quan(7,3,3,4), vds_quan(7,3,2,4),  ...
          vds_quan(7,4,1,4), vds_quan(7,4,3,4), vds_quan(7,4,2,4))
fprintf(' 12M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(13,1,1,4), vds_quan(13,1,3,4), vds_quan(13,1,2,4),  ...
          vds_quan(13,2,1,4), vds_quan(13,2,3,4), vds_quan(13,2,2,4),  ...
          vds_quan(13,3,1,4), vds_quan(13,3,3,4), vds_quan(13,3,2,4),  ...
          vds_quan(13,4,1,4), vds_quan(13,4,3,4), vds_quan(13,4,2,4))
fprintf(' 24M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(25,1,1,4), vds_quan(25,1,3,4), vds_quan(25,1,2,4),  ...
          vds_quan(25,2,1,4), vds_quan(25,2,3,4), vds_quan(25,2,2,4),  ...
          vds_quan(25,3,1,4), vds_quan(25,3,3,4), vds_quan(25,3,2,4),  ...
          vds_quan(25,4,1,4), vds_quan(25,4,3,4), vds_quan(25,4,2,4))
fprintf(' 36M & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          vds_quan(37,1,1,4), vds_quan(37,1,3,4), vds_quan(37,1,2,4),  ...
          vds_quan(37,2,1,4), vds_quan(37,2,3,4), vds_quan(37,2,2,4),  ...
          vds_quan(37,3,1,4), vds_quan(37,3,3,4), vds_quan(37,3,2,4),  ...
          vds_quan(37,4,1,4), vds_quan(37,4,3,4), vds_quan(37,4,2,4))
fprintf(' \\hline\n')
fprintf('\\end{tabular}\n')
fprintf('\\end{table}\n')