%
% Generate Figures 6 and 7
%
% by Stephane Lhuissier

clear all; clc;

addpath '../library'
addpath '../MS-SBVARs/benchmark'

load '../data/EAdata_1999M10_2016M6.mat'

nstates = 4;
nvar    = 4;
nexo    = 1;
lags    = 4;

bupp     = 84;    % upper error band (percentile)
blow     = 16;    % lower error band (percentile)
bmed     = 50;    % impulse response percentile

ndraws   = 1000;

namesvar   = {'Industrial production','Prices','EONIA','Excess Bond Premium'};
nameylabel = {'Log Units'; 'Log Units'; '%'; 'p.p'};
         
% first year to use in estimation
yrStart = 2000;
% first quarter or month to use in estimation
qmStart = 2;
% last year to use in estimation
yrEnd = 2016;
% last quarter or month to use in estimation
qmEnd = 6;
% create date 
[date, n] = fn_calyrqm(12, [yrStart qmStart], [yrEnd qmEnd]);
qdates=zeros(n,1);
for ki=1:n
   qdates(ki) = date(1,1) + (date(1,2)+ki-2)/12;
end
% ordering
xdd = [IP P RE EBP];

% Simple regressions for a constant-parameters (reduced-form) VAR model
[xtx,xty,yty,fss,phi,y,ncoef,xr,Bh,e] = fn_dataxy(nvar,lags,xdd,[],0,nexo);

%
xsim_ctf1 = zeros(nvar*lags+nexo,fss,ndraws);
xsim_ctf2 = zeros(nvar*lags+nexo,fss,ndraws);

load load_draws_msVAR.mat

draws1 = 1;
draws2 = 0;

while draws1<=ndraws

    %
    Agbs = Agibbs(:,:,:,draws1);
    Fgbs = Fgibbs(:,:,:,draws1);
    Zgbs = Zgibbs(:,:,:,draws1);
    Qgbs = Qgibbs(:,:,:,draws1);
    
    %
    Egbs = zeros(nvar,nstates);
    Bgbs = zeros(size(Fgbs));
    %
    for h_idx=1:nstates
        Egbs(:,h_idx) = sqrt(diag(Zgbs(:,:,h_idx)));
        Egbs(:,h_idx) = sqrt(diag(Zgbs(:,:,h_idx)));
        Egbs(:,h_idx) = sqrt(diag(Zgbs(:,:,h_idx)));
        Egbs(:,h_idx) = sqrt(diag(Zgbs(:,:,h_idx)));
        %
        Bgbs(:,:,h_idx) = Fgbs(:,:,h_idx)/Agbs(:,:,h_idx);
    end
    
    %
	rootsinv1 = sort(abs(fn_varoots(Bgbs(:,:,1),nvar,lags)));
    rootsinv2 = sort(abs(fn_varoots(Bgbs(:,:,2),nvar,lags)));
    
    if rootsinv1(end) <=1.01 && rootsinv2(end) <=1.01 % rule out explosive paths
        draws2 = draws2 + 1;
        
        %
        Qstar = kron(Qgbs(:,:,1),Qgbs(:,:,2));

        % Evaluate the likelihood
        [logLik, lik_mat, pr_st0, pr_stl0] = lik_ms_sbvar(xdd, Agbs, Fgbs, Egbs, Qstar, nstates, lags);

        % Kim (1994) filter 
        [pr_sT, pr_joint_sT] = SmoothedProbabilities(pr_st0, pr_stl0, Qstar);

        % Historical path of ST={1,2,3,4} at each period t
        ST = zeros(fss,1);
        for i_idx = 1:fss
            ST(i_idx,1) = bingen1(pr_sT(i_idx,:));
        end

        % Historical path of structural shocks
        egbs = zeros(fss,nvar);
        for j_idx=1:fss
            egbs(j_idx,:) = (y(j_idx,:)*Agbs(:,:,ST(j_idx)) - phi(j_idx,:)*Fgbs(:,:,ST(j_idx)))*sqrt(Zgbs(:,:,ST(j_idx)));
        end

        % Countefactural simulations
        Agbs_ctf = zeros(nvar,nvar,nstates);
        Fgbs_ctf = zeros(nvar*lags+1,nvar,nstates);
        %
        for k_idx = 1:nstates
            Agbs_ctf(:,:,k_idx) = Agbs(:,:,1);
            Fgbs_ctf(:,:,k_idx) = Fgbs(:,:,1);
        end
        
        egbs(:,4) = zeros(fss,1); % suppress all credit supply shocks
        
        xsim_ctf2(:,:,draws2) = ms_simulation(Agbs_ctf,Fgbs_ctf,Zgbs,egbs,ST,phi(1,1:end)',fss);

        %egbs(:,4) = zeros(fss,1); % suppress all credit supply shocks

        xsim_ctf1(:,:,draws2) = ms_simulation(Agbs,Fgbs,Zgbs,egbs,ST,phi(1,1:end)',fss);
    end
    draws1 = draws1 + 1;
end

xsim_ctf1 = xsim_ctf1(1:nvar,:,1:draws2);
xsim_ctf2 = xsim_ctf2(1:nvar,:,1:draws2);

% memory allocation
hd1_quan = zeros(fss,nvar,3);
hd2_quan = zeros(fss,nvar,3);

% sort HDs
sort_hd1 = sort(permute(xsim_ctf1,[2 1 3]),3);
sort_hd2 = sort(permute(xsim_ctf2,[2 1 3]),3);
    
% computing mean, upper and lower bands for HDs 
hd1_quan(:,:,1) = sort_hd1(:,:,round(draws2*blow/100));
hd1_quan(:,:,2) = sort_hd1(:,:,round(draws2*bmed/100));
hd1_quan(:,:,3) = sort_hd1(:,:,round(draws2*bupp/100));
%
hd2_quan(:,:,1) = sort_hd2(:,:,round(draws2*blow/100));
hd2_quan(:,:,2) = sort_hd2(:,:,round(draws2*bmed/100));
hd2_quan(:,:,3) = sort_hd2(:,:,round(draws2*bupp/100));

% Make EONIA and EBP in percentage.
for ii=3:4
    hd1_quan(:,ii,1) = hd1_quan(:,ii,1)*100;
    hd1_quan(:,ii,2) = hd1_quan(:,ii,2)*100;
    hd1_quan(:,ii,3) = hd1_quan(:,ii,3)*100;
    %
    hd2_quan(:,ii,1) = hd2_quan(:,ii,1)*100;
    hd2_quan(:,ii,2) = hd2_quan(:,ii,2)*100;
    hd2_quan(:,ii,3) = hd2_quan(:,ii,3)*100;
    %
    y(:,ii) = y(:,ii)*100;
end

t=qdates';
%
make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.11 0.08], [0.07 0.04], [0.07 0.03]);
if ~make_it_tight,  clear subplot;  end

figure
for ii=1:nvar
    subplot(2,2,ii)
    h = fill([t, fliplr(t)], [hd2_quan(:,ii,3)',fliplr(hd2_quan(:,ii,1)')], 'y');
    hold on
    a=plot(qdates,y(:,ii),'k','Linewidth',1.5);
    hold on
    b=plot(qdates,hd2_quan(:,ii,2),'--b','Linewidth',1.5);
    xlim([1998 2018])
    if ii==1 || ii==2
        ylim([min([hd2_quan(:,ii,3); hd2_quan(:,ii,1);y(:,ii)])*0.99 max([hd2_quan(:,ii,3); hd2_quan(:,ii,1);y(:,ii)])*1.01])
    elseif ii==3
        ylim([min([hd2_quan(:,ii,3); hd2_quan(:,ii,1);y(:,ii)])*1.45 max([hd2_quan(:,ii,3); hd2_quan(:,ii,1);y(:,ii)])*1.05])
    elseif ii==4
        ylim([-1.0 2.0])
    end

    if ii==2
       legend([a,b,h],'Actual','Counterfactual (median)','Counterfactual (68% error bands)','Location','SouthEast')
    end
    
    set(h,'FaceColor',[255/255 250/255 205/255]); % yellow color
	set(h,'EdgeColor','y');
    title(namesvar(ii))
    xlabel('years')
    ylabel(nameylabel(ii))
    grid on
end

set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[10 8]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 10 8]);

set(gcf,'renderer','painters');
%eval(['print -dpdf Fig6']);

%
make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.11 0.08], [0.07 0.04], [0.07 0.03]);
if ~make_it_tight,  clear subplot;  end

figure
for ii=1:nvar
    subplot(2,2,ii)
    h = fill([t, fliplr(t)], [hd1_quan(:,ii,3)',fliplr(hd1_quan(:,ii,1)')], 'y');
    hold on
    a=plot(qdates,y(:,ii),'k','Linewidth',1.5);
    hold on
    b=plot(qdates,hd1_quan(:,ii,2),'--b','Linewidth',1.5);
    xlim([1998 2018])
    if ii==1 || ii==2
        ylim([min([hd1_quan(:,ii,3); hd1_quan(:,ii,1);y(:,ii)])*0.99 max([hd1_quan(:,ii,3); hd1_quan(:,ii,1);y(:,ii)])*1.01])
    elseif ii==3
        ylim([min([hd1_quan(:,ii,3); hd1_quan(:,ii,1);y(:,ii)])*1.45 max([hd1_quan(:,ii,3); hd1_quan(:,ii,1);y(:,ii)])*1.05])
    elseif ii==4
        ylim([-1.0 2.0])
    end
    
    if ii==2
       legend([a,b,h],'Actual','Counterfactual (median)','Counterfactual (68% error bands)','Location','SouthEast')
    end

	set(h,'FaceColor',[255/255 250/255 205/255]); % yellow color
	set(h,'EdgeColor','y');
    title(namesvar(ii))
    xlabel('years')
    ylabel(nameylabel(ii))
    grid on
end

set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[10 8]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 10 8]);

set(gcf,'renderer','painters');
%eval(['print -dpdf Fig7']);

